==> phplist-2.10.3.tgz: lists/admin/lan/es/common.php <==
<?php

# file with common texts for translation

$lan = array(
  'logout' => 'Desconectarse',
  'Main Page' => 'P&aacute;gina principal',
  'user' => 'Usuario',
  'error' => 'Error',
  'version' => 'versi&oacute;n',
  'powered by' => 'funciona con',
  'fatalerror' => 'Error cr&iacute;tico',
  'warning' => 'Aviso',
  'information' => 'Informaci&oacute;n',
  'help' => 'ayuda',
  'about' => 'informaci&oacute;n',
  'lists' => 'listas',
  'send a message' => 'Enviar un mensaje',
  'users' => 'usuarios',
  'manage users' => 'gestionar usuarios',
  'messages' => 'mensajes',
  'statistics' => 'estad&iacute;sticas',
  'process queue' => 'procesar cola de mensajes',
  'configure' => 'configurar',
  'Subscribe Pages' => 'P&aacute;ginas de suscripci&oacute;n',
  'Send a prepared message' => 'Enviar un mensaje preparado',
  'Prepare a message' => 'Preparar un mensaje',
  'Templates' => 'Patrones',
  'View Bounces' => 'Ver rebotes',
  'Process Bounces' => 'Procesar rebotes',
  'Eventlog' => 'Registro de eventos',
  'Sunday' => 'Domingo',
  'Monday' => 'Lunes',
  'Tuesday' => 'Martes',
  'Wednesday' => 'Mi&eacute;rcoles',
  'Thursday' => 'Jueves',
  'Friday' => 'Viernes',
  'Saturday' => 'S&aacute;bado',
  'January' => 'Enero',
  'February' => 'Febrero',
  'March' => 'Marzo',
  'April' => 'Abril',
  'May' => 'Mayo',
  'June' => 'Junio',
  'July' => 'Julio',
  'August' => 'Agosto',
  'September' => 'Septiembre',
  'October' => 'Octubre',
  'November' => 'Noviembre',
  'December' => 'Diciembre',
  'Jan' => 'I',
  'Feb' => 'II',
  'Mar' => 'III',
  'Apr' => 'IV',
  'May' => 'V',
  'Jun' => 'VI',
  'Jul' => 'VII',
  'Aug' => 'VIII',
  'Sep' => 'IX',
  'Oct' => 'X',
  'Nov' => 'XI',
  'Dec' => 'XII',
  # from sendemaillib
  'sendingtextonlyto' => 'Enviando texto plano a',
  'sendingmessage' => 'Enviando mensaje',
  'withsubject' => 'con asunto',
  'to' => 'a',
  'admininitfailure' => 'Fall&oacute; la inicializaci&oacute;n de la
  autenticaci&oacute;n del administrador',
  'yourpassword' => 'Su contrase&ntilde;a para phplist',
  'yourpasswordis' => 'Su contrase&ntilde;a es',
  'passwordsent' => 'Su contrase&ntilde;a ha sido enviada por email',
  'cannotsendpassword' => 'No se pudo enviar la contrase&ntilde;a',
  'ipchanged' => 'Su direcci&oacute;n IP ha cambiado. Por motivos de
  seguridad debe conectarse de nuevo',
  'goodbye' => 'adi&oacute;s',
  'goodmorning' => 'buenos d&iacute;as',
  'goodafternoon' => 'buenas tardes',
  'goodevening' => 'buenas noches',
  'safemodewarning' => 'En modo seguro no todo funcionar&aacute; como
  se espera',
  'magicquoteswarning' => 'Las cosas funcionar&aacute;n mejor con PHP magic_quotes_gpc = <b>on</b>',
  'magicruntimewarning' => 'Las cosas funcionar&aacute;n mejor con PHP magic_quotes_runtime = off',
  'noxml' => 'Est&aacute; intentando utilizar RSS, pero en su PHP no
  se ha inclu&iacute;do XML',
  'warnopenbasedir' => 'Est&aacute;n operando restricciones
  open_basedir, lo que puede explicar el aviso que sigue',
  'warnattachmentrepository' => 'El directorio para archivos adjuntos
  no existe o est&aacute; protegido contra escritura',
  'nofpdf' => 'Est%aacute; intentando utilizar funciones PDF sin haber
  cargado FPDF',
  'warnpageroot' => 'El directorio ra&iacute;z establecido en su
  configuraci&oacute;n no concuerda con la direcci&oacute;n
  actual<br/>Compruebe su fichero de configuraci&oacute;n.',
  'pagenotfoundinplugin' => 'Lo sentimos, no se encontr&oacute; esta
  p&aacute;gina en el m&oacute;dulo (plugin)',
  'notimplemented' => 'Lo sentimos, esta funci&oacute;n aun no existe',
  'noaccess' => 'No tiene sufucientes privilegios para ver esta p&aacute;gina',
  'nohelpavailable' => 'Lo sentimos, aun no hay ayuda pera este tema: ',
  'closewindow' => 'Cerrar esta ventana',
  'success' => 'logrado',
  'failed' => 'fracasado',
  'default login is' => 'La conexi&oacute;n por defecto es',
  'with password' => 'con contrase&ntilde;a',
  'name' => 'Nombre',
  'password' => 'Contrase&ntilde;a',
  'enter' => 'Presione &#171;Enter&#187;',
  'forgot password' => '&#191;Ha olvidado su contrase&ntilde;a?',
  'enter your email' => 'Introduzca su email',
  'send password' => 'Enviar contrase&ntilde;a',
  'An image exists on the server, check this box to keep the existing
  one' => 'En el servidor ya hay una imgen, marcar esta casilla para
  mantener la imagen existente',
  'View Image' => 'Ver imagen',
  'Upload new image' => 'Cargar una imagen nueva',
  'textline' => 'l&iacute;nea de texto',
  'textarea' => '&aacute;rea de texto',
  'date' => 'fecha',
  'checkbox' => 'casilla de verificaci&oacute;n',
  'radio' => 'radiobot&oacute;n',
  'select' => 'seleccionar',
  'checkboxgroup' => 'grupo de casillas de verificaci&oacute;n',
  'unnamed list' => 'Lista sin nombre',
  'unknown' => 'Desconocido',
  'very little time' => 'muy poco tiempo',
  'A process for this page is already running and it was still alive'
  => 'Ya se estaba ejecutando un proceso en esta p&aacute;gina, y
  todav&iacute;a estaba en marcha',
  'seconds ago' => 'segundos atr&aacute;s',
  'We have been waiting too long, I guess the other process is still
  going ok' => 'Hemos esperado ya demasiado, suponemos que el otro
  proceso sigue funcionando bien',
  'Sleeping for 20 seconds, aborting will quit' => 'Descansando 20
  segundos, para cerrar interrumpir',
  'No Image was found' => 'No se encontr&oacute; ninguna imagen',
  'messages' => 'Mensajes',
  'bounces' => 'Rebotes',
  'bounce' => 'rebote',
  'msg' => 'mensaje', # as in short for message
  'time' => 'hora',
  'sent' => 'enviado',
  'text' => 'texto',
  'html' => 'html',
  #
  # new for 2.9.5
  'delete user' => 'eliminar usuario',
  'unconfirm user' => 'marcar al usuario &#171;no confirmado&#187;',
  'delete user and bounce' => 'eliminar usuario y rebote',
  'unconfirm user and delete bounce' => 'marcar al usuario &#171;no confirmado&#187; y eliminar el rebote',
  'blacklist user and delete bounce' => 'colocar al usuario en la lista negra y eliminar el rebote',
  'delete bounce' => 'eliminar el rebote',
  'blacklist user' => 'colocar al usuario en la lista negra',
  'manage bounces' => 'Gestionar rebotes',

);

?>

==> phplist-2.10.14p1.tgz: lists/admin/lan/es/common.php <==
<?php

# file with common texts for translation

$lan = array(
  'logout' => 'Desconectarse',
  'Main Page' => 'P&aacute;gina principal',
  'user' => 'Usuario',
  'error' => 'Error',
  'version' => 'versi&oacute;n',
  'powered by' => 'funciona con',
  'fatalerror' => 'Error cr&iacute;tico',
  'warning' => 'Aviso',
  'information' => 'Informaci&oacute;n',
  'help' => 'ayuda',
  'about' => 'informaci&oacute;n',
  'lists' => 'listas',
  'send a message' => 'Enviar un mensaje',
  'users' => 'usuarios',
  'manage users' => 'gestionar usuarios',
  'messages' => 'mensajes',
  'statistics' => 'estad&iacute;sticas',
  'process queue' => 'procesar cola de mensajes',
  'configure' => 'configurar',
  'Subscribe Pages' => 'P&aacute;ginas de suscripci&oacute;n',
  'Send a prepared message' => 'Enviar un mensaje preparado',
  'Prepare a message' => 'Preparar un mensaje',
  'Templates' => 'Plantillas',
  'View Bounces' => 'Ver rebotes',
  'Process Bounces' => 'Procesar rebotes',
  'Eventlog' => 'Registro de eventos',
  'Sunday' => 'Domingo',
  'Monday' => 'Lunes',
  'Tuesday' => 'Martes',
  'Wednesday' => 'Mi&eacute;rcoles',
  'Thursday' => 'Jueves',
  'Friday' => 'Viernes',
  'Saturday' => 'S&aacute;bado',
  'January' => 'Enero',
  'February' => 'Febrero',
  'March' => 'Marzo',
  'April' => 'Abril',
  'May' => 'Mayo',
  'June' => 'Junio',
  'July' => 'Julio',
  'August' => 'Agosto',
  'September' => 'Septiembre',
  'October' => 'Octubre',
  'November' => 'Noviembre',
  'December' => 'Diciembre',
  'Jan' => 'Ene',
  'Feb' => 'Feb',
  'Mar' => 'Mar',
  'Apr' => 'Abr',
  'shortMay' => 'May',
  'Jun' => 'Jun',
  'Jul' => 'Jul',
  'Aug' => 'Ago',
  'Sep' => 'Set',
  'Oct' => 'Oct',
  'Nov' => 'Nov',
  'Dec' => 'Dic',
  # from sendemaillib
  'sendingtextonlyto' => 'Enviando texto plano a',
  'sendingmessage' => 'Enviando mensaje',
  'withsubject' => 'con asunto',
  'to' => 'a',
  'admininitfailure' => 'Fall&oacute; la inicializaci&oacute;n de la
  autenticaci&oacute;n del administrador',
  'yourpassword' => 'Su contrase&ntilde;a para phplist',
  'yourpasswordis' => 'Su contrase&ntilde;a es',
  'passwordsent' => 'Su contrase&ntilde;a ha sido enviada por email',
  'cannotsendpassword' => 'No se pudo enviar la contrase&ntilde;a',
  'ipchanged' => 'Su direcci&oacute;n IP ha cambiado. Por motivos de
  seguridad debe conectarse de nuevo',
  'goodbye' => 'adi&oacute;s',
  'goodmorning' => 'buenos d&iacute;as',
  'goodafternoon' => 'buenas tardes',
  'goodevening' => 'buenas noches',
  'safemodewarning' => 'En modo seguro no todo funcionar&aacute; como
  se espera',
  'magicquoteswarning' => 'Las cosas funcionar&aacute;n mejor con PHP magic_quotes_gpc = <b>on</b>',
  'magicruntimewarning' => 'Las cosas funcionar&aacute;n mejor con PHP magic_quotes_runtime = off',
  'noxml' => 'Est&aacute; intentando utilizar RSS, pero en su PHP no
  se ha inclu&iacute;do XML',
  'warnopenbasedir' => 'Est&aacute;n operando restricciones
  open_basedir, lo que puede explicar el aviso que sigue',
  'warnattachmentrepository' => 'El directorio para archivos adjuntos
  no existe o est&aacute; protegido contra escritura',
  'nofpdf' => 'Est%aacute; intentando utilizar funciones PDF sin haber
  cargado FPDF',
  'warnpageroot' => 'El directorio ra&iacute;z establecido en su
  configuraci&oacute;n no concuerda con la direcci&oacute;n
  actual<br/>Compruebe su fichero de configuraci&oacute;n.',
  'pagenotfoundinplugin' => 'Lo sentimos, no se encontr&oacute; esta
  p&aacute;gina en el m&oacute;dulo (plugin)',
  'notimplemented' => 'Lo sentimos, esta funci&oacute;n aun no existe',
  'noaccess' => 'No tiene sufucientes privilegios para ver esta p&aacute;gina',
  'nohelpavailable' => 'Lo sentimos, aun no hay ayuda pera este tema: ',
  'closewindow' => 'Cerrar esta ventana',
  'success' => 'logrado',
  'failed' => 'fracasado',
  'default login is' => 'La conexi&oacute;n por defecto es',
  'with password' => 'con contrase&ntilde;a',
  'name' => 'Nombre',
  'password' => 'Contrase&ntilde;a',
  'enter' => 'Presione &#171;Enter&#187;',
  'forgot password' => '&#191;Ha olvidado su contrase&ntilde;a?',
  'enter your email' => 'Introduzca su email',
  'send password' => 'Enviar contrase&ntilde;a',
  'An image exists on the server, check this box to keep the existing
  one' => 'En el servidor ya hay una imgen, marcar esta casilla para
  mantener la imagen existente',
  'View Image' => 'Ver imagen',
  'Upload new image' => 'Cargar una imagen nueva',
  'textline' => 'l&iacute;nea de texto',
  'textarea' => '&aacute;rea de texto',
  'date' => 'fecha',
  'checkbox' => 'casilla de verificaci&oacute;n',
  'radio' => 'radiobot&oacute;n',
  'select' => 'seleccionar',
  'checkboxgroup' => 'grupo de casillas de verificaci&oacute;n',
  'unnamed list' => 'Lista sin nombre',
  'unknown' => 'Desconocido',
  'very little time' => 'muy poco tiempo',
  'A process for this page is already running and it was still alive'
  => 'Ya se estaba ejecutando un proceso en esta p&aacute;gina, y
  todav&iacute;a estaba en marcha',
  'seconds ago' => 'segundos atr&aacute;s',
  'We have been waiting too long, I guess the other process is still
  going ok' => 'Hemos esperado ya demasiado, suponemos que el otro
  proceso sigue funcionando bien',
  'Sleeping for 20 seconds, aborting will quit' => 'Descansando 20
  segundos, para cerrar interrumpir',
  'No Image was found' => 'No se encontr&oacute; ninguna imagen',
  'messages' => 'Mensajes',
  'bounces' => 'Rebotes',
  'bounce' => 'rebote',
  'msg' => 'mensaje', # as in short for message
  'time' => 'hora',
  'sent' => 'enviado',
  'text' => 'texto',
  'html' => 'html',
  #
  # new for 2.9.5
  'delete user' => 'eliminar usuario',
  'unconfirm user' => 'marcar al usuario &#171;no confirmado&#187;',
  'delete user and bounce' => 'eliminar usuario y rebote',
  'unconfirm user and delete bounce' => 'marcar al usuario &#171;no confirmado&#187; y eliminar el rebote',
  'blacklist user and delete bounce' => 'colocar al usuario en la lista negra y eliminar el rebote',
  'delete bounce' => 'eliminar el rebote',
  'blacklist user' => 'colocar al usuario en la lista negra',
  'manage bounces' => 'Gestionar rebotes',

);

?>
